import { Material } from 'three';
/**
 * Helper class around an object storing materials by name.
 * Optionally, create and store default materials.
 */
declare class MaterialStore {
    private materials;
    /**
     * Creates a new {@link MaterialStore}.
     * @param {boolean} createDefaultMaterials
     */
    constructor(createDefaultMaterials: boolean);
    /**
     * Set materials loaded by any supplier of an Array of {@link Material}.
     *
     * @param {Map<string, Material>} newMaterials Object with named {@link Material}
     * @param {boolean} forceOverrideExisting boolean Override existing material
     */
    addMaterials(newMaterials: Map<string, Material>, forceOverrideExisting: boolean): void;
    addMaterialsFromObject(newMaterials: Record<string, Material>, forceOverrideExisting: boolean): void;
    /**
     * Returns the mapping object of material name and corresponding material.
     *
     * @returns {Map<string, Material>}
     */
    getMaterials(): Map<string, Material>;
    /**
     *
     * @param {String} materialName
     * @returns {Material}
     */
    getMaterial(materialName: string): Material | undefined;
    /**
     * Removes all materials
     */
    clearMaterials(): void;
}
export { MaterialStore };
//# sourceMappingURL=MaterialStore.d.ts.map