import { Material } from 'three';
declare type MaterialCloneInstructions = {
    materialNameOrg: string;
    materialProperties: {
        name: string;
        vertexColors: number;
        flatShading: boolean;
    };
};
/**
 * Static functions useful in the context of handling materials.
 */
declare class MaterialUtils {
    /**
     * Adds the provided material to the provided materials object if the material does not exists.
     * Use force override existing material.
     *
     * @param {Map<string, Material>} materialsObject
     * @param {Material} material
     * @param {string} materialName
     * @param {boolean} force
     * @param {boolean} [log] Log messages to the console
     */
    static addMaterial(materialsObject: Map<string, Material>, materialName: string, material: Material, force: boolean, log?: boolean): void;
    /**
     * Transforms the named materials object to an object with named jsonified materials.
     *
     * @param {Map<string, Material>}
     * @returns {Map<string, unknown>} Map of Materials in JSON representation
     */
    static getMaterialsJSON(materialsObject: Map<string, Material>): Map<string, unknown>;
    /**
     * Clones a material according the provided instructions.
     *
     * @param {Map<string, Material>} materials
     * @param {MaterialCloneInstructions} materialCloneInstruction
     * @param {boolean} [log]
     */
    static cloneMaterial(materials: Map<string, Material>, materialCloneInstruction: MaterialCloneInstructions, log?: boolean): Material | undefined;
}
export { MaterialUtils, MaterialCloneInstructions };
//# sourceMappingURL=MaterialUtils.d.ts.map