import { Material } from 'three';
import { MaterialCloneInstructions } from './MaterialUtils';
import { PayloadType } from './WorkerTaskManager';
import { DataTransportPayload } from './DataTransport';
export declare type MaterialsTransportPayloadType = PayloadType & {
    materials: Map<string, Material>;
    materialsJson: Map<string, unknown>;
    multiMaterialNames: Map<number, string>;
    cloneInstructions: MaterialCloneInstructions[];
};
export declare class MaterialsTransportPayload extends DataTransportPayload implements MaterialsTransportPayloadType {
    type: string;
    materials: Map<string, Material>;
    materialsJson: Map<string, unknown>;
    multiMaterialNames: Map<number, string>;
    cloneInstructions: MaterialCloneInstructions[];
}
/**
 * Define a structure that is used to ship materials data between main and workers.
 */
export declare class MaterialsTransportPayloadUtils {
    static packMaterialsTransportPayload(payload: MaterialsTransportPayload, cloneBuffers: boolean): {
        payload: MaterialsTransportPayloadType;
        transferables: Transferable[];
    };
    /**
     * @param {MaterialsTransportDef} transportObject
     * @return {MaterialsTransport}
     */
    static unpackMaterialsTransportPayload(payload: MaterialsTransportPayload, transportObject: MaterialsTransportPayload): void;
    /**
     * Set an object containing named materials.
     * @param {Map<string, Material>} materials
     */
    static setMaterials(payload: MaterialsTransportPayload, materials: Map<string, Material>): void;
    /**
     * Removes all textures and null values from all materials
     */
    static cleanMaterials(payload: MaterialsTransportPayload): void;
    static cleanMaterial(material: Material): Material;
    /**
     * Tell whether a multi-material was defined
     * @return {boolean}
     */
    static hasMultiMaterial(payload: MaterialsTransportPayload): boolean;
    /**
     * Returns a single material if it is defined or null.
     * @return {Material|null}
     */
    static getSingleMaterial(payload: MaterialsTransportPayload): Material | undefined;
    /**
     * Adds contained material or multi-material the provided materials object or it clones and adds new materials according clone instructions.
     *
     * @param {Map<string, Material>} materials
     * @param {boolean} log
     *
     * @return {Material|Material[]|undefined}
     */
    static processMaterialTransport(payload: MaterialsTransportPayload, materials: Map<string, Material>, log?: boolean): undefined[] | Material | Material[] | undefined;
}
//# sourceMappingURL=MaterialsTransport.d.ts.map