import { BufferAttribute, BufferGeometry, InterleavedBufferAttribute, Mesh } from 'three';
import { PayloadType } from './WorkerTaskManager';
import { DataTransportPayload } from './DataTransport';
import { MaterialsTransportPayload } from './MaterialsTransport';
export declare type MeshTransportPayloadType = PayloadType & {
    geometryType: 0 | 1 | 2;
    bufferGeometry: BufferGeometry | Record<string, unknown> | undefined;
    meshName: string | undefined;
    materialsTransportPayload: MaterialsTransportPayload | undefined;
};
export declare class MeshTransportPayload extends DataTransportPayload implements MeshTransportPayloadType {
    type: string;
    geometryType: 0 | 1 | 2;
    bufferGeometry: BufferGeometry | Record<string, unknown> | undefined;
    meshName: string | undefined;
    materialsTransportPayload: MaterialsTransportPayload;
}
export declare class MeshTransportPayloadUtils {
    /**
     * Set the {@link BufferGeometry} and geometry type that can be used when a mesh is created.
     *
     * @param {BufferGeometry} bufferGeometry
     * @param {number} geometryType [0=Mesh|1=LineSegments|2=Points]
     */
    static setBufferGeometry(payload: MeshTransportPayload, bufferGeometry: BufferGeometry | undefined, geometryType: 0 | 1 | 2): void;
    /**
     * Sets the mesh and the geometry type [0=Mesh|1=LineSegments|2=Points]
     * @param {Mesh} mesh
     * @param {number} geometryType
     */
    static setMesh(payload: MeshTransportPayload, mesh: Mesh, geometryType: 0 | 1 | 2): void;
    /**
     * @param {boolean} cloneBuffers
     */
    static packMeshTransportPayload(payload: MeshTransportPayload, cloneBuffers: boolean): {
        payload: MeshTransportPayload;
        transferables: Transferable[];
    };
    /**
     * Package {@link BufferGeometry} and prepare it for transport.
     *
     * @param {boolean} cloneBuffers Clone buffers if their content shall stay in the current context.
     */
    static packGeometryBuffers(cloneBuffers: boolean, bufferGeometry: BufferGeometry | undefined, buffers: Map<string, ArrayBufferLike>): void;
    static addAttributeToBuffers(name: string, input: BufferAttribute | InterleavedBufferAttribute | null | undefined, cloneBuffer: boolean, buffers: Map<string, ArrayBufferLike>): void;
    static unpackMeshTransportPayload(payload: MeshTransportPayloadType, cloneBuffers: boolean): MeshTransportPayload;
    /**
     * Reconstructs the {@link BufferGeometry} from the raw buffers.
     * @param {boolean} cloneBuffers
     */
    static reconstructBuffer(cloneBuffers: boolean, transferredGeometry: BufferGeometry | Record<string, unknown>): BufferGeometry;
    static assignAttributeFromTransfered(bufferGeometry: BufferGeometry, input: BufferAttribute | InterleavedBufferAttribute | undefined, attrName: string, cloneBuffer: boolean): void;
}
//# sourceMappingURL=MeshTransport.d.ts.map